.. _app_migrating:

.. toctree::
   :maxdepth: 2

=======================================
Migrating applications between releases
=======================================

This document describes how a developer of murano application can update
existing packages to make them synchronized with all implemented features
and requirements.

.. include:: app_migrating/app_migrate_to_juno.rst
.. include:: app_migrating/app_migrate_to_kilo.rst
.. include:: app_migrating/app_migrate_to_liberty.rst
